/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#include <Connection/SDSConnector.hpp>
#include <DxcConfig.hpp>
#include <DxcDataTypes.hpp>

using namespace Dxc;

SDSConnector::SDSConnector(DxcCallback* cb)
        : DxcConnectorImp(cb), slsock_(-1), dasock_(-1), srsock_(-1)
{
    initConnections();
    acceptConnections();
}

void SDSConnector::initConnections()
{
    connect("localhost", DxcConfig::getInstance()->getInt("SL_SDS_PORT"), &slsock_);
}

void SDSConnector::sendMessage(const DxcData *msg)
{
    string msgType(typeid(*msg).name());
    if ((msgType == typeid(FaultInjectData).name()))
    {
        DxcConnectorImp::transmit(srsock_, msg);
    }
    if (msgType == typeid(ScenarioStatusData).name())
    {
        DxcConnectorImp::transmit(slsock_, msg);
        DxcConnectorImp::transmit(dasock_, msg);
        DxcConnectorImp::transmit(srsock_, msg);
    }
    else if ((msgType == typeid(ErrorData).name()))
    {
        DxcConnectorImp::transmit(dasock_, msg);
        DxcConnectorImp::transmit(srsock_, msg);
    }
    else if ((msgType == typeid(SensorData).name() ||
              msgType == typeid(CommandData).name()))
    {
        DxcConnectorImp::transmit(dasock_, msg);
        DxcConnectorImp::transmit(srsock_, msg);
    }
}

void SDSConnector::acceptConnections()
{
    DxcConnectorImp::acceptConnection(DxcConfig::getInstance()->getInt("SDS_SR_PORT"), &srsock_);
    DxcConnectorImp::acceptConnection(DxcConfig::getInstance()->getInt("SDS_DA_PORT"), &dasock_);
}
