/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#include <DataTypes/FaultInjectData.hpp>

using namespace std;
using namespace Dxc;

FaultInjectData::FaultInjectData(Timestamp timestamp,
                                 bool isInjection,
                                 const string& componentID,
                                 const string& modeID,
                                 const map<string, string>& parameterMap)
        : DxcData(timestamp),
        isInjection_(isInjection),
        componentID_(componentID),
        modeID_(modeID),
        parameterMap_(parameterMap)
{
}

FaultInjectData::FaultInjectData(Timestamp timestamp,
                                 bool isInjection,
                                 const string& componentID,
                                 const string& modeID)
        : DxcData(timestamp),
        isInjection_(isInjection),
        componentID_(componentID),
        modeID_(modeID)
{
}

FaultInjectData::FaultInjectData(Timestamp timestamp,
                                 bool isInjection,
                                 Literal * fault,
                                 vector<Literal *>& parameterMap)
        : DxcData(timestamp),
        isInjection_(isInjection)
{
    componentID_ = *(fault->getId());

    const StringValue * modeID = dynamic_cast<const StringValue*>(fault->getValue());
    if (modeID)
        modeID_ = modeID->get();

    vector<Literal *>::const_iterator pi;

    for (pi = parameterMap.begin(); pi != parameterMap.end(); pi++)
    {
        Literal * keyValPair = *pi;
        const StringValue * strVal = dynamic_cast<const StringValue*>(keyValPair->getValue());
        if (strVal)
            parameterMap_[*(keyValPair->getId())] = strVal->get();
    }
}

FaultInjectData* FaultInjectData::clone() const
{
    return new FaultInjectData(*this);
}

ostream &FaultInjectData::put(ostream &out) const
{
    out << "faultInjection @" << this->getTimeStamp() << " ";
    out << "isInjection = "
    << (this->isInjection() ? "true" : "false");
    out << ", fault = {"
    << this->getComponentID() << " = "
    << this->getModeID() << "} ";
    out << ", parameters = {";

    map<string, string>::const_iterator i = parameterMap_.begin();

    for (; i != parameterMap_.end(); i++)
    {
        if (i != parameterMap_.begin())
            out << ", ";

        out << i->first << " = " << "'" << i->second << "'";
    }

    out << " }; " << endl;

    out.flush();

    return out;
}

bool FaultInjectData::isInjection() const
{
    return isInjection_;
}

string FaultInjectData::getComponentID() const
{
    return componentID_;
}

string FaultInjectData::getModeID() const
{
    return modeID_;
}

map<string, string> FaultInjectData::getParameterMap() const
{
    return parameterMap_;
}
