/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#ifndef SCENARIO_STATUS_HPP
#define SCENARIO_STATUS_HPP

#include <typeinfo>
#include <DxcDefs.hpp>
#include <DataTypes/DxcData.hpp>

namespace Dxc
{
/**
 * @brief Data structure for scenario status messages.
 */
class DXCAPI_EXPORT ScenarioStatusData : public DxcData
{
public:
    static const std::string SDS_AWAITING_DA; /**< */
    static const std::string SR_READY; /**< */
    /**
     * @brief A Diagnosis Algorithm
     *  sends DA_READY to indicate
     *  it's prepared to receive data.
     */
    static const std::string DA_READY;
    static const std::string STARTED; /**< */

    /**
     * @brief Signals scenario end. DAs must finalize and
     *  exit properly or risk termination.
     *
     * The SDS_ENDED message signals the end of the scenario. All processes
     * must clean up and exit. Some time is given to DAs to compute and
     * send final diagnoses (the exact time is determined by the DXC config
     * file), after which they are terminated.
     */
    static const std::string SDS_ENDED;
    static const std::string DA_ENDED;
    static const std::string UNKNOWN; /**< */

    /**
     * @brief Constructor.
     *
     * @param timestamp - message timestamp.
     * @param status - current scenario status
     *        (ScenarioStatusData::STARTED, ScenarioStatusData::ENDED, etc).
     */
    ScenarioStatusData(Timestamp timestamp, const std::string& status);

    /**
     * @brief Constructs with timestamp set to current time.
     *
     * @param status - current scenario status
     *        (ScenarioStatusData::STARTED, ScenarioStatusData::ENDED, etc).
     */
    ScenarioStatusData(const std::string& status);

    /**
     * @brief Returns status.
     */
    std::string getStatus() const;

    virtual ScenarioStatusData* clone() const;

    virtual ostream &put(ostream &) const;

private:
    ScenarioStatusData();

    std::string status_;
};
}

#endif
