/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#ifndef DXC_CONFIG_HPP
#define DXC_CONFIG_HPP

#include <map>
#include <string>
#include <DxcDefs.hpp>

namespace Dxc
{

/**
 * @brief Access DXC configuration.
 *
 * Reads keys and values stored in the DXC config file.
 */
class DXCAPI_EXPORT DxcConfig
{
public:
    /**
     * @brief Loads DXC configuration and returns an instance of DxcConfig.
     */
    static DxcConfig* getInstance();

    /**
     * @brief Get the value of a key.
     *
     * @param key - key to return value of.
     * @return value pointed to by key
     */
    std::string get(const std::string& key);

    /**
     * @brief Get the (int) value of a key.
     *
     * @param key - key to return value of.
     * @return value pointed to by key
     */
    int getInt(const std::string& key);

    /**
     * @brief Get the (long) value of a key.
     *
     * @param key - key to return value of.
     * @return value pointed to by key
     */
    long getLong(const std::string& key);

private:
    DxcConfig();

    std::map<std::string, std::string> myMap_;

};

}

#endif
