/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia
  
  The DXC Framework is free software: you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by the 
  Free Software Foundation, either version 3 of the License, or (at your 
  option) any later version. 

  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more 
  details. 

  You should have received a copy of the GNU Lesser General Public License 
  along with this program. If not, see <http://www.gnu.org/licenses/> 
 */
package org.dxc.api.datatypes;

import java.io.PrintStream;
import org.dxc.api.datatypes.DxcData;

/**
 * Command datatype.
 */
public class CommandData extends DxcData {

    private String commandID;

    private Value value;

    /**
     * Constructor.
     * 
     * @param timestamp
     *            - message timestamp
     * @param commandID
     *            - command ID string
     * @param value
     *            - the Value of the command
     */
    public CommandData(long timestamp, String commandID, Value value) {
        super(timestamp);
        this.commandID = (commandID == null) ? "" : commandID;
        this.value = (value == null) ? new StringValue("") : value;
    }

    /**
     * Get command ID string
     */
    public String getCommandID() {
        return this.commandID;
    }

    /**
     * Get command Value
     */
    public Value getValue() {
        return this.value;
    }

    public PrintStream put(PrintStream out) {
        out.append("command @");
        out.append(Long.toString(this.getTimeStamp()));
        out.append(" " + commandID + " = ");
        value.put(out);
        out.append(";\n");
        return out;
    }
}
