/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia
  
  The DXC Framework is free software: you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by the 
  Free Software Foundation, either version 3 of the License, or (at your 
  option) any later version. 

  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more 
  details. 

  You should have received a copy of the GNU Lesser General Public License 
  along with this program. If not, see <http://www.gnu.org/licenses/> 
 */
package org.dxc.api.datatypes;

import java.io.PrintStream;

/**
 * The root of the Dxc data definition hierarchy.
 */
public abstract class DxcData {

    private long timestamp;

    /**
     * Construct with current time as timestamp
     * 
     */
    public DxcData() {
        this.timestamp = System.currentTimeMillis();
    }

    /**
     * Constructor
     * 
     * @param timestamp
     *            - the desired timestamp in milliseconds since 1970-1-1
     *            00:00:00 GMT
     */
    public DxcData(long timestamp) {
        this.timestamp = timestamp;
    }

    /**
     * Get message timestamp
     * 
     * @return The message timestamp in milliseconds since 1970-1-1 00:00:00 GMT
     */
    public long getTimeStamp() {
        return timestamp;
    }

    /**
     * Set timestamp for DxcData
     * 
     * Although timestamps can be freely manipulated by users in local instances
     * of DxcData, they serve only for informative purposes. There is no
     * guarantee that a DxcData message recipient won't overwrite the timestamp
     * with the time of message arrival.
     * 
     * @param timestamp
     *            - The desired timestamp in milliseconds since 1970-1-1
     *            00:00:00 GMT
     */
    public void setTimeStamp(long timestamp) {
        this.timestamp = timestamp;
    }

    /**
     * Prints DxcData in standardized, parseable format.
     */
    public abstract PrintStream put(PrintStream out);

    /**
     * Static method to obtain current time.
     * 
     * @return The current time in milliseconds since 1970-1-1 00:00:00 GMT
     */
    public static long getCurrentTime() {
        return System.currentTimeMillis();
    }
}