/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia
  
  The DXC Framework is free software: you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by the 
  Free Software Foundation, either version 3 of the License, or (at your 
  option) any later version. 

  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more 
  details. 

  You should have received a copy of the GNU Lesser General Public License 
  along with this program. If not, see <http://www.gnu.org/licenses/> 
 */
package org.dxc.evaluator;

import org.dxc.api.datatypes.DxcData;
import org.dxc.api.datatypes.DiagnosisData;
import org.dxc.api.datatypes.FaultInjectData;
import org.dxc.api.datatypes.ProfilingData;
import org.dxc.api.DxcCallback;
import java.util.List;
import java.util.LinkedList;

public class ScenarioResult extends DxcCallback {
    private List<FaultInjectData> faultInjections;
    private List<DiagnosisData> diagnoses;
    private long startTime;
    private String name;
    private long cpuTime;
    private long maxMem;

    public ScenarioResult(String scenarioName) {
        startTime = -1;
        name = scenarioName;
        faultInjections = new LinkedList<FaultInjectData>();
        diagnoses = new LinkedList<DiagnosisData>();
    }

    public void processData(DxcData data) {
        if (startTime < 0) {
            startTime = data.getTimeStamp();
        }

        if (data instanceof FaultInjectData) {
            long tDelta = data.getTimeStamp() - startTime;

            data.setTimeStamp(tDelta);
            faultInjections.add((FaultInjectData) data);
        } else if (data instanceof DiagnosisData) {
            long tDelta = data.getTimeStamp() - startTime;

            data.setTimeStamp(tDelta);
            diagnoses.add((DiagnosisData) data);
        } else if (data instanceof ProfilingData) {
            ProfilingData pd = (ProfilingData) data;
            cpuTime = pd.getCpuTime();
            maxMem = pd.getMaxMem();
        }
    }

    public List<DiagnosisData> getDiagnoses() {
        return diagnoses;
    }

    public List<FaultInjectData> getFaultInjections() {
        return faultInjections;
    }

    public String getName() {
        return name;
    }

    public long getCpuTime() {
        return this.cpuTime;
    }

    public long getMaxMem() {
        return this.maxMem;
    }
}
