/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#include <fstream>
#include <iostream>
#include <Parser/tinyxml.hpp>
#include <DataTypes/DxcException.hpp>
#include <DAConfig.hpp>

using namespace Dxc;
using namespace std;

DAConfig::DAConfig(string configFile)
{
    string::size_type n = configFile.find_last_of("/\\");
    directory_ = configFile.substr(0, n + 1);

    TiXmlDocument tXml(configFile);

    if (!tXml.LoadFile())
        throw DxcException("Unable to open DA config file.");

    TiXmlElement* nd = tXml.FirstChild("diagnosisAlgorithm")->FirstChildElement("name");
    if (nd)
        name_ = nd->FirstChild()->Value();

    nd = nd->NextSiblingElement("application");
    if (nd)
    {
        binName_ = nd->FirstChild()->Value();
        platform_ = nd->Attribute("platform");
        const char* cl = nd->Attribute("mainClass");
        if (cl)
            javaClass_ = cl;
    }

    nd = nd->NextSiblingElement("supportedSystems");
    if (nd)
    {
        nd = nd->FirstChildElement("system");
        for (; nd; nd = nd->NextSiblingElement("system"))
        {
            string system, args;

            TiXmlElement* cn = nd->FirstChildElement("name");
            if (cn)
                system = cn->FirstChild()->Value();

            cn = nd->FirstChildElement("args");
            if (cn)
                args = cn->FirstChild()->Value();

            if (!system.empty())
                systemToArgs_[system] = args;
        }
    }
}

string DAConfig::getName() const
{
    return name_;
}

string DAConfig::getBinName() const
{
    return binName_;
}

string DAConfig::getJavaClass() const
{
    return javaClass_;
}

string DAConfig::getArgs(const string& system) const
{
    map<string, string>::const_iterator i = systemToArgs_.find(system);
    if (i != systemToArgs_.end())
        return i->second;
    else
        return "";
}

string DAConfig::getPlatform() const
{
    return platform_;
}

string DAConfig::getDirectory() const
{
    return directory_;
}

vector<string> DAConfig::getSupportedSystems() const
{
    vector<string> ret;

    map<string, string>::const_iterator i = systemToArgs_.begin();
    for (; i != systemToArgs_.end(); i++)
    {
        ret.push_back(i->first);
    }
    return ret;
}
